@@ -7,21 +7,23 @@ test_that("lang.aff", {
     expect_equal(lang.aff("Baltic"), c("Lithuanian", "Latvian"))
     expect_equal(lang.aff(df), c(my_langs1 = "Lithuanian",
                                  my_langs2 = "Latvian"))
-    expect_equal(lang.aff(c("Brythonic", "Goidelic")), c("Old Cornish",
+    expect_equal(lang.aff(c("Brythonic", "Goidelic")), c("Old South-West British",
                                                          "Welsh",
                                                          "Old-Middle Welsh",
-                                                         "Breton",
                                                          "Cornish",
+                                                         "Vannetais",
+                                                         "Breton",
                                                          "Early Irish",
                                                          "Irish",
                                                          "Scottish Gaelic",
                                                          "Manx"))
     expect_equal(lang.aff(c("Brythonic", "Goidelic"), list = TRUE),
-                 list(c("Old Cornish",
+                 list(c("Old South-West British",
                         "Welsh",
                         "Old-Middle Welsh",
-                        "Breton",
-                        "Cornish"),
+                        "Cornish",
+                        "Vannetais",
+                        "Breton"),
                       c("Early Irish",
                         "Irish",
                         "Scottish Gaelic",
